require "slidepay"
require "spec_helper"

describe SlidePay::ACH::Balance do
  describe "retrieve" do
    it "append location_id to the url" do
      SlidePay.should_receive(:post).with(hash_including(path: "settlement/balance/4")).and_return(a_response_object)
      SlidePay::ACH::Balance.retrieve(4)
    end

    it "should pass auth information to SlidePay.post" do
      auth_hash = { token: "TOKEN", api_key: "API_KEY", endpoint: "ENDPOINT" }
      SlidePay.should_receive(:post).with(hash_including(path: "settlement/balance/1", token: "TOKEN")).and_return(a_response_object)
      SlidePay::ACH::Balance.retrieve(1, auth_hash)
    end

    it "should raise an error if balance could not be retrieved" do
      SlidePay.should_receive(:post).and_return(a_response_object(failed_balance_response))
      expect {
       SlidePay::ACH::Balance.retrieve(1)
      }.to raise_error
    end

    it "should raise an error if no location_id is provided" do
      expect {
        SlidePay::ACH::Balance.retrieve()
      }.to raise_error
    end

    it "should return the balance value if call is successful" do
      SlidePay.should_receive(:post).and_return(a_response_object(successful_balance_response))
      balance = SlidePay::ACH::Balance.retrieve(1)

      expect(balance).to eq(15.00)
    end
  end
end

