require "slidepay"
require "spec_helper"

# Settlement descriptors
valid_descriptor = { bank_account_id: 1, amount: 1.01 }
valid_descriptor_list = [{ bank_account_id: 1, amount: 1.01 }, { bank_account_id: 2, amount: 2.02 }]
valid_descriptor_list_string_keys = [{ "bank_account_id" => 1, "amount" => 1.01 }, { "bank_account_id" => 2, "amount" => 2.02 }]
invalid_descriptor_list = [{ bank_account_id: 1, amount: 1.01 }, { amount: 2.02 }]
invalid_descriptor_no_bank_account_id = { amount: 1.23 }
invalid_descriptor_no_amount = { bank_account_id: 1 }

# Settlement order objects
def settlement_order(settlement_list)
  {
    company_id: 18,
    location_id: 622,
    settlement_list: settlement_list,
    notes: "Test Settlement"
  }
end

def settlement_order_string_keys
  {
    "company_id" => 18,
    "location_id" => 622,
    "settlement_list" => [{ "bank_account_id" => 1, "amount" => 1.01 }, { "bank_account_id" => 2, "amount" => 2.02 }],
    "notes" => "Test Settlement"
  }
end

def settlement_order_symbol_keys
  {
    company_id: 18,
    location_id: 622,
    settlement_list: [{ bank_account_id: 1, amount: 1.01 }, { bank_account_id: 2, amount: 2.02 }],
    notes: "Test Settlement"
  }
end

def settlement_order_no_company_id(settlement_list)
  {
    location_id: 622,
    settlement_list: settlement_list,
    notes: "Test Settlement"
  }
end

def settlement_order_no_location_id(settlement_list)
  {
    company_id: 18,
    settlement_list: settlement_list,
    notes: "Test Settlement"
  }
end

def settlement_order_no_settlement_list
  {
    company_id: 18,
    location_id: 622,
    notes: "Test Settlement"
  }
end

describe SlidePay::ACH::Settlement do
  describe "process" do
    it "should accept a hash " do
      SlidePay.should_receive(:post).and_return(a_response_object)

      SlidePay::ACH::Settlement.process(settlement_order(valid_descriptor_list))
    end

    it "should call the SlidePay.post method" do
      SlidePay.should_receive(:post).and_return(a_response_object)
      SlidePay::ACH::Settlement.process(settlement_order(valid_descriptor_list))
    end

    describe "failure cases" do
      it "should raise an error if the settlment_order is not a hash" do
        expect { SlidePay::ACH::Settlement.process("I AM A STRING") }.to raise_error
      end

      it "should raise an error if company_id is not supplied" do
        expect { SlidePay::ACH::Settlement.process(settlement_order_no_company_id(valid_descriptor_list)) }.to raise_error
      end

      it "should raise an error if location_id is not supplied" do
        expect { SlidePay::ACH::Settlement.process(settlement_order_no_location_id(valid_descriptor_list)) }.to raise_error
      end

      it "should raise an error if settlement_list is not supplied" do
        expect { SlidePay::ACH::Settlement.process(settlement_order_no_settlement_list) }.to raise_error
      end

      it "should raise an error if a descriptor is supplied without a bank_account_id" do
        expect { SlidePay::ACH::Settlement.process(settlement_order([invalid_descriptor_no_bank_account_id])) }.to raise_error
      end

      it "should raise an error if a descriptor is supplied without an amount" do
        expect { SlidePay::ACH::Settlement.process(settlement_order([invalid_descriptor_no_amount])) }.to raise_error
      end

      it "should raise an error if one descriptor in a list is invalid" do
        expect { SlidePay::ACH::Settlement.process(settlement_order(invalid_descriptor_list)) }.to raise_error
      end
    end

    describe "acceptable parameters" do
      it "should accept symbol keys in the settlement_order hash" do
        SlidePay.should_receive(:post).and_return(a_response_object)
        SlidePay::ACH::Settlement.process(settlement_order_symbol_keys)
      end

      it "should accept string keys in the settlement_order hash" do
        SlidePay.should_receive(:post).and_return(a_response_object)
        SlidePay::ACH::Settlement.process(settlement_order_string_keys)
      end
    end

  end
end

