$:.unshift(File.join(File.dirname(__FILE__), '../'))

require "codeclimate-test-reporter"
CodeClimate::TestReporter.start

require 'multi_json'
require 'pathname'

if Pathname.new('environment.rb').exist?
  require 'environment'
end

module SlidePay
  TEST_EMAIL = ENV["email"]
  TEST_PASSWORD = ENV["password"]
  TEST_API_KEY = ENV["api_key"]
end

def a_response_object(json=nil)
  if json
    SlidePay::Response.new(json)
  else
    SlidePay::Response.new(successful_object_response)
  end
end

def set_global_api_key_from_env
  SlidePay.api_key = SlidePay::TEST_API_KEY
end

def set_global_api_key
  SlidePay.api_key = "TEST_API_KEY"
end

def set_global_token
  SlidePay.token = "TEST_TOKEN"
end

def set_global_endpoint
  SlidePay.endpoint = "TEST_ENDPOINT"
end

def clear_auth_data
  SlidePay.api_key = nil
  SlidePay.token = nil
end

def clear_endpoint
  SlidePay.endpoint = nil
end

def clear_slidepay
  SlidePay.token = nil
  SlidePay.api_key = nil
  SlidePay.endpoint = nil
end

def object_from_response(json)
  MultiJson.decode(json)
end

def failed_ach_retreival_response
  <<-eos
  {
    "custom" : null,
    "method" : "POST",
    "operation" : "POST retrieval manual",
    "id" : 0,
    "milliseconds" : "184.58",
    "obj" : null,
    "success" : false,
    "timezone" : "",
    "endpoint" : "https://dev.getcube.com:65532",
    "data" : {
      "error_code" : "92",
      "error_text" : "Unable to process transaction.  This transaction would cause you to exceed your weekly ACH retrieval limit.",
      "error_file" : "l_post_manual_retrieval.cs"
    },
    "data_md5" : "BD6F9EBF0801734DE1148116C491ECEF"
  }
  eos
end


def successful_deletion_response
  <<-eos
  {
    "success": true,
    "custom": null,
    "operation": "DELETE person",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": "",
    "method": "delete",
    "obj": "person",
    "id": 398,
    "milliseconds": "3376.74",
    "data": "Success",
    "data_md5": "02CDC0A219FB85758EC8A9693478EC26"
  }
  eos
end

def failed_deletion_response
  <<-eos
  {
    "success": false,
    "custom": null,
    "operation": "DELETE person",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": "",
    "method": "delete",
    "obj": "person",
    "id": 0,
    "milliseconds": "47.85",
    "data": {
      "error_code": "1",
      "error_file": "l_delete_handler.cs",
      "error_text": "The requested object was not found."
    },
    "data_md5": null
  }
  eos
end

def successful_object_response
  <<-eos
  {
    "success": true,
    "custom": null,
    "operation": "GET person",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": null,
    "method": "GET",
    "obj": null,
    "id": 0,
    "milliseconds": "31.25",
    "data": {
      "id": "1",
      "name": "Dog the Bounty Hunter"
    },
    "data_md5": "15D13569C731E9D77ABDCB3348A2EBDD"
  }
  eos
end

def failed_object_response
  <<-eos
  {
    "success": false,
    "custom": null,
    "operation": "GET person",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": null,
    "method": "GET",
    "obj": null,
    "id": 0,
    "milliseconds": "31.25",
    "data": {
      "error_code": "4",
      "error_file": "i_http_handler.cs",
      "error_text": "ERROR_TEXT"
    },
    "data_md5": "15D13569C731E9D77ABDCB3348A2EBDD"
  }
  eos
end

def successful_endpoint_response
  <<-eos
  {
    "success": true,
    "custom": null,
    "operation": "GET endpoint",
    "endpoint": "https://api.getcube.com:65532",
    "timezone": null,
    "method": "GET",
    "obj": null,
    "id": 0,
    "milliseconds": "31.25",
    "data": "https://api.getcube.com:65532/rest.svc/API/",
    "data_md5": "15D13569C731E9D77ABDCB3348A2EBDD"
  }
  eos
end

def failed_endpoint_response
  <<-eos
  {
    "success": false,
    "custom": null,
    "operation": "GET endpoint",
    "endpoint": null,
    "timezone": null,
    "method": "GET",
    "obj": null,
    "id": 0,
    "milliseconds": "0.00",
    "data": {
      "error_code": "4",
      "error_file": "i_http_handler.cs",
      "error_text": "Unable to process your request at this time.  Unable to locate an endpoint for your account."
    },
    "data_md5": null
  }
  eos
end

def successful_array_response
  <<-eos
  {
    "success": true,
    "custom": null,
    "operation": "GET customer",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": "",
    "method": "get",
    "obj": null,
    "id": 0,
    "milliseconds": "15.62",
    "data": [
      {
        "customer_id": 211,
        "company_id": 213,
        "location_id": 285,
        "user_master_id": 297,
        "first_name": "Father",
        "middle_name": "",
        "last_name": "Yummy Bears",
        "company_name": "",
        "address_1": "",
        "address_2": "",
        "address_3": "",
        "city": "",
        "state": "",
        "postal_code": "",
        "country": "",
        "email": "",
        "home_phone": "",
        "cell_phone": "1234567890",
        "twitter_id": "",
        "facebook_email": "",
        "homepage": "",
        "active": 1,
        "created": "2013-09-06T04:05:49",
        "last_update": "2013-09-06T04:05:49"
      },
      {
        "customer_id": 210,
        "company_id": 213,
        "location_id": 285,
        "user_master_id": 297,
        "first_name": "Customer",
        "middle_name": "",
        "last_name": "Robot Rabbit",
        "company_name": "",
        "address_1": "",
        "address_2": "",
        "address_3": "",
        "city": "",
        "state": "",
        "postal_code": "",
        "country": "",
        "email": "",
        "home_phone": "",
        "cell_phone": "2222222222",
        "twitter_id": "",
        "facebook_email": "",
        "homepage": "",
        "active": 1,
        "created": "2013-09-05T16:57:33",
        "last_update": "2013-09-05T16:57:33"
      }
    ],
    "data_md5": "2B4A5BF8C70C97022E4824643E96C695"
  }
  eos
end

def payment_where_sfa
  [{ :field => "created", :condition => "equals", :value => "12/13/2013" }]
end

def payment_greater_than_sfa
  [{ field: "created", condition: "greater_than", value: "10/08/2013 23:28:40"}]
end

def payment_less_than_sfa
  [{ field: "created", condition: "less_than", value: "10/08/2012"}]
end

def payment_between_sfa
  [{ field: "created", condition: "greater_than", value: "10/08/2013 23:28"},
   { field: "created", condition: "less_than", value: "10/08/2013 23:28:40"}]
end

def payment_search_response
  <<-eos
  {
    "success": true,
    "custom": null,
    "operation": "PUT search payment",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": "",
    "method": "put",
    "obj": "payment",
    "id": 0,
    "milliseconds": "15.62",
    "data": [
      {
        "payment_id": 10923,
        "order_master_id": 4133,
        "company_id": 18,
        "location_id": 14,
        "customer_id": 0,
        "user_master_id": 32,
        "auto_capture": 1,
        "device_type": "",
        "method": "CreditCard",
        "method_other": "",
        "stored_payment_guid": "6f9a90c4-69c3-41cc-8dcd-299a0b6915c3",
        "cc_type": "Visa",
        "cc_present": 0,
        "cc_number": "4111111111111111",
        "cc_expiry_month": "11",
        "cc_expiry_year": "11",
        "cc_name_on_card": "",
        "cc_address_1": "",
        "cc_address_2": "",
        "cc_address_3": "",
        "cc_city": "",
        "cc_state": "",
        "cc_billing_zip": "11111",
        "cc_country": "",
        "cc_track1data": "",
        "cc_track2data": "",
        "cc_cvv2": "",
        "cc_redacted_number": "************1111",
        "encryption_vendor": "",
        "encryption_ksn": "",
        "encryption_device_serial": "",
        "amount": 14.01,
        "tip_amount": 0.00,
        "is_refund": null,
        "refund_payment_id": null,
        "is_chargeback": 0,
        "under_review": 0,
        "notes": "Goods or Services",
        "signature_cloud_object_id": null,
        "provider": "ipcommerce-cube-vantiv",
        "provider_payment_token": "",
        "provider_transaction_token": "DummyTransaction",
        "provider_is_approved": "true",
        "provider_status_code": "00",
        "provider_status_message": "Transaction Approved",
        "provider_transaction_state": "Authorized",
        "provider_approval_code": "000000",
        "provider_capture_state": "DummyTransaction",
        "provider_capture_status_message": "",
        "settlement_transaction_token": "",
        "provider_fee_amount": 0.00,
        "vendor_id": "cube",
        "vendor_markup_percent": 0.00,
        "vendor_markup_pertrans": 0.00,
        "fee_percentage": 3.50,
        "fee_percentage_amount": 0.50,
        "fee_per_transaction": 0.00,
        "fee_interchange": null,
        "fee_total": 0.50,
        "ip_address": "50.152.207.105",
        "latitude": "38.0000",
        "longitude": "-97.0000",
        "country": "US",
        "distance_from_location": 1368.70,
        "processor_time_ms": 0.00,
        "total_time_ms": null,
        "capture_requested": null,
        "capture_confirmed": null,
        "created": "2013-10-08T23:29:01",
        "last_update": "2013-10-08T23:29:01"
      }
    ],
    "data_md5": "96F66EF31C54F3D0F63F8D52BFC1B3A4"
  }
  eos
end

def bank_account_array_response
  <<-eos
  {
    "success": true,
    "custom": null,
    "operation": "GET bank_account",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": "",
    "method": "get",
    "obj": null,
    "id": 0,
    "milliseconds": "15.62",
    "data": [
      {
        "bank_account_id": 211,
        "company_id": 213,
        "location_id": 285,
        "user_master_id": 297,
        "account_first_name": "Father",
        "account_last_name": "Yummy Bears",
        "name": "ACCOUNT 211",
        "routing_number": "211123456",
        "account_number": "211211211",
        "created": "2013-09-06T04:05:49",
        "last_update": "2013-09-06T04:05:49"
      },
      {
        "customer_id": 210,
        "company_id": 213,
        "location_id": 285,
        "user_master_id": 297,
        "account_first_name": "Customer",
        "account_last_name": "Robot Rabbit",
        "name": "ACCOUNT 210",
        "routing_number": "210123456",
        "account_number": "210210210",
        "created": "2013-09-05T16:57:33",
        "last_update": "2013-09-05T16:57:33"
      }
    ],
    "data_md5": "2B4A5BF8C70C97022E4824643E96C695"
  }
  eos
end

def successful_token_detail_response
  <<-eos
  {
    "success": true,
    "custom": null,
    "operation": "GET token detail",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": "",
    "method": "get",
    "obj": null,
    "id": 0,
    "milliseconds": "15.62",
    "data": {
      "created": "2013-09-15T01:11:20",
      "server_name": "cubeuswdev1",
      "endpoint": "https://dev.getcube.com:65532",
      "email": "matt@slidepay.com",
      "password": null,
      "ip_address": "12.12.12.12",
      "random": null,
      "timezone": "",
      "company_id": 99,
      "company_name": "AWESOME CO.",
      "location_id": 99,
      "location_name": "AWESOME LOC.",
      "user_master_id": 99,
      "first_name": "Matt",
      "last_name": "Rothstein",
      "is_clerk": 1,
      "is_locmgr": 1,
      "is_comgr": 1,
      "is_admin": 0,
      "is_isv": 0
    },
    "data_md5": "2B4A5BF8C70C97022E4824643E96C695"
  }
  eos
end

def failed_token_detail_response
  <<-eos
  {
    "success": false,
    "custom": null,
    "operation": "get /API/token/detail",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": null,
    "method": "get",
    "obj": null,
    "id": 0,
    "milliseconds": "15.62",
    "data": {
      "error_code": "6",
      "error_file": "i_http_handler.cs",
      "error_text": "Token not present.  Please login."
    },
    "data_md5": null
  }
  eos
end

def successful_payment_response
  <<-eos
  {
    "success": true,
    "custom": null,
    "operation": "POST payment simple",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": "",
    "method": "post",
    "obj": null,
    "id": 0,
    "milliseconds": "15.62",
    "data": {
      "payment_id": "12",
      "order_master_id": "10",
      "method": "CreditCard",
      "amount": "1.22"
    },
    "data_md5": "2B4A5BF8C70C97022E4824643E96C695"
  }
  eos
end

def uncaptured_payment_response
  <<-eos
  {
    "custom" : null,
    "method" : "PUT",
    "operation" : "PUT search payment",
    "id" : 0,
    "milliseconds" : "135.73",
    "obj" : "payment",
    "success" : true,
    "timezone" : "",
    "endpoint" : "https://dev.getcube.com:65532",
    "data" : [
      {
        "under_review" : 0,
        "cc_redacted_number" : "************1111",
        "fee_total" : 0.34,
        "latitude" : "37.33",
        "cc_state" : "",
        "provider_approval_code" : "000000",
        "company_id" : 559,
        "created" : "2014-01-20T17:58:49",
        "settlement_transaction_token" : "",
        "vendor_markup_pertrans" : 0,
        "fee_interchange" : null,
        "cc_track2data" : "",
        "notes" : "Ski Boots",
        "method_other" : "",
        "cc_address_1" : "",
        "total_time_ms" : null,
        "vendor_markup_percent" : 0,
        "cc_cvv2" : "",
        "amount" : 1.32,
        "provider_transaction_token" : "DummyTransaction",
        "provider_payment_token" : "",
        "provider_capture_state" : "DummyTransaction",
        "cc_name_on_card" : "",
        "provider_status_code" : "00",
        "provider_transaction_state" : "Authorized",
        "longitude" : "-121.94",
        "signature_cloud_object_id" : null,
        "cc_billing_zip" : "11111",
        "cc_present" : 0,
        "provider_is_approved" : "true",
        "location_id" : 662,
        "cc_type" : "Visa",
        "cc_city" : "",
        "provider" : "ipcommerce-cube-vantiv",
        "cc_address_2" : "",
        "ip_address" : "50.193.11.137",
        "encryption_device_serial" : "",
        "fee_per_transaction" : 0.3,
        "customer_id" : 0,
        "tip_amount" : 0,
        "country" : "US",
        "fee_percentage_amount" : 0.04,
        "method" : "CreditCard",
        "vendor_id" : "slidepay",
        "encryption_vendor" : "",
        "stored_payment_guid" : "978554c7-2994-442f-81ef-d7c6486da407",
        "order_master_id" : 5146,
        "is_refund" : null,
        "provider_fee_amount" : 0,
        "cc_expiry_month" : "11",
        "fee_percentage" : 2.9,
        "encryption_ksn" : "",
        "cc_track1data" : "",
        "cc_number" : "4111111111111111",
        "cc_address_3" : "",
        "is_chargeback" : 0,
        "distance_from_location" : 8.8,
        "processor_time_ms" : 0,
        "cc_country" : "",
        "user_master_id" : 689,
        "auto_capture" : 1,
        "cc_expiry_year" : "11",
        "provider_status_message" : "Transaction Approved",
        "refund_payment_id" : null,
        "device_type" : "",
        "last_update" : "2014-01-20T17:58:49",
        "capture_confirmed" : null,
        "payment_id" : 11784,
        "capture_requested" : null,
        "provider_capture_status_message" : ""
      }
    ]
  }
  eos
end

def unsettled_payment_response
  <<-eos
  {
    "custom" : null,
    "method" : "PUT",
    "operation" : "PUT search payment",
    "id" : 0,
    "milliseconds" : "135.73",
    "obj" : "payment",
    "success" : true,
    "timezone" : "",
    "endpoint" : "https://dev.getcube.com:65532",
    "data" : [
      {
        "under_review" : 0,
        "cc_redacted_number" : "************1111",
        "fee_total" : 0.34,
        "latitude" : "37.33",
        "cc_state" : "",
        "provider_approval_code" : "000000",
        "company_id" : 559,
        "created" : "2014-01-20T17:58:49",
        "settlement_transaction_token" : "",
        "vendor_markup_pertrans" : 0,
        "fee_interchange" : null,
        "cc_track2data" : "",
        "notes" : "Ski Boots",
        "method_other" : "",
        "cc_address_1" : "",
        "total_time_ms" : null,
        "vendor_markup_percent" : 0,
        "cc_cvv2" : "",
        "amount" : 1.32,
        "provider_transaction_token" : "DummyTransaction",
        "provider_payment_token" : "",
        "provider_capture_state" : "DummyTransaction",
        "cc_name_on_card" : "",
        "provider_status_code" : "00",
        "provider_transaction_state" : "Authorized",
        "longitude" : "-121.94",
        "signature_cloud_object_id" : null,
        "cc_billing_zip" : "11111",
        "cc_present" : 0,
        "provider_is_approved" : "true",
        "location_id" : 662,
        "cc_type" : "Visa",
        "cc_city" : "",
        "provider" : "ipcommerce-cube-vantiv",
        "cc_address_2" : "",
        "ip_address" : "50.193.11.137",
        "encryption_device_serial" : "",
        "fee_per_transaction" : 0.3,
        "customer_id" : 0,
        "tip_amount" : 0,
        "country" : "US",
        "fee_percentage_amount" : 0.04,
        "method" : "CreditCard",
        "vendor_id" : "slidepay",
        "encryption_vendor" : "",
        "stored_payment_guid" : "978554c7-2994-442f-81ef-d7c6486da407",
        "order_master_id" : 5146,
        "is_refund" : null,
        "provider_fee_amount" : 0,
        "cc_expiry_month" : "11",
        "fee_percentage" : 2.9,
        "encryption_ksn" : "",
        "cc_track1data" : "",
        "cc_number" : "4111111111111111",
        "cc_address_3" : "",
        "is_chargeback" : 0,
        "distance_from_location" : 8.8,
        "processor_time_ms" : 0,
        "cc_country" : "",
        "user_master_id" : 689,
        "auto_capture" : 1,
        "cc_expiry_year" : "11",
        "provider_status_message" : "Transaction Approved",
        "refund_payment_id" : null,
        "device_type" : "",
        "last_update" : "2014-01-20T17:58:49",
        "capture_confirmed" : null,
        "payment_id" : 11784,
        "capture_requested" : null,
        "provider_capture_status_message" : ""
      }
    ]
  }
  eos
end

def settled_payment_response
  <<-eos
  {
    "custom" : null,
    "method" : "PUT",
    "operation" : "PUT search payment",
    "id" : 0,
    "milliseconds" : "135.73",
    "obj" : "payment",
    "success" : true,
    "timezone" : "",
    "endpoint" : "https://dev.getcube.com:65532",
    "data" : [
      {
        "under_review" : 0,
        "cc_redacted_number" : "************1111",
        "fee_total" : 0.04,
        "latitude" : "37.3276089784472",
        "cc_state" : "",
        "provider_approval_code" : "046123",
        "company_id" : 12,
        "created" : "2014-01-13T21:40:33",
        "settlement_transaction_token" : "2d88ce9b-d8d4-477e-8177-41573baefbf0",
        "vendor_markup_pertrans" : 0,
        "fee_interchange" : null,
        "cc_track2data" : "",
        "notes" : "Custom",
        "method_other" : "",
        "cc_address_1" : "",
        "total_time_ms" : 5399,
        "vendor_markup_percent" : 0,
        "cc_cvv2" : "",
        "amount" : 1,
        "provider_transaction_token" : "2521989576C240DD92E3DEA50E83B59A",
        "provider_payment_token" : "",
        "provider_capture_state" : "Captured",
        "cc_name_on_card" : "",
        "provider_status_code" : "00",
        "provider_transaction_state" : "Authorized",
        "longitude" : "-121.8869275811915",
        "signature_cloud_object_id" : null,
        "cc_billing_zip" : "20015",
        "cc_present" : 0,
        "provider_is_approved" : "true",
        "location_id" : 285,
        "cc_type" : "Visa",
        "cc_city" : "",
        "provider" : "ipcommerce-cube-vantiv",
        "cc_address_2" : "",
        "ip_address" : "174.240.0.128",
        "encryption_device_serial" : "",
        "fee_per_transaction" : 0,
        "customer_id" : 0,
        "tip_amount" : 0,
        "country" : "US",
        "fee_percentage_amount" : 0.04,
        "method" : "CreditCard",
        "vendor_id" : "cube",
        "encryption_vendor" : "",
        "stored_payment_guid" : "ec1866d1-e909-4882-bac5-19ff7f396782",
        "order_master_id" : 5054,
        "is_refund" : null,
        "provider_fee_amount" : 0.04,
        "cc_expiry_month" : "04",
        "fee_percentage" : 3.5,
        "encryption_ksn" : "",
        "cc_track1data" : "",
        "cc_number" : "4111111111111111",
        "cc_address_3" : "",
        "is_chargeback" : 0,
        "distance_from_location" : 11.54,
        "processor_time_ms" : 3093.55,
        "cc_country" : "",
        "user_master_id" : 12,
        "auto_capture" : 1,
        "cc_expiry_year" : "12",
        "provider_status_message" : "Transaction Approved",
        "refund_payment_id" : null,
        "device_type" : "iphone-cct",
        "last_update" : "2014-01-17T21:00:00",
        "capture_confirmed" : "2014-01-15T20:30:03",
        "payment_id" : 11123,
        "capture_requested" : "2014-01-14T20:00:02",
        "provider_capture_status_message" : ""
      }
    ]
  }
  eos
end


def failed_payment_response
  <<-eos
  {
    "success": false,
    "custom": null,
    "operation": "POST payment simple",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": null,
    "method": "post",
    "obj": null,
    "id": 0,
    "milliseconds": "15.62",
    "data": {
      "status_message": "TEST_PAYMENT_FAILED_MESSAGE",
      "order_master_id": "10",
      "method": "CreditCard",
      "amount": "1.22"
    },
    "data_md5": null
  }
  eos
end

def api_key_json
  <<-eos
  {
    "api_key_id": 99,
    "company_id": 99,
    "location_id": 99,
    "user_master_id": 99,
    "guid": "TEST_API_KEY",
    "active": 1,
    "notes": "TEST DESCRIPTION",
    "created": "2013-09-15T05:58:16",
    "last_update": "2013-09-15T05:58:16"
  }
  eos
end

def successful_token_response
  <<-eos
  {
    "success": true,
    "custom": null,
    "operation": "GET login",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": null,
    "method": "get",
    "obj": null,
    "id": 0,
    "milliseconds": "0.00",
    "data": "TOKEN_FROM_THE_BEYOND",
    "data_md5": "2A28E72629AA92B440F3A74F7CA4F9D5"
  }
  eos
end

def failed_token_response
  <<-eos
  {
    "success": false,
    "custom": null,
    "operation": "GET login",
    "endpoint": "https://dev.getcube.com:65532",
    "timezone": null,
    "method": "get",
    "obj": null,
    "id": 0,
    "milliseconds": "0.00",
    "data": {
      "error_code": "5",
      "error_file": "l_login.cs",
      "error_text": "Authorization failed."
    },
    "data_md5": null
  }
  eos
end

def successful_retrieval_retrieve_response
  <<-eos
  {
    "custom" : null,
    "method" : "GET",
    "operation" : "GET retrieval",
    "id" : 0,
    "milliseconds" : "31.25",
    "obj" : "retrieval",
    "success" : true,
    "timezone" : "",
    "endpoint" : "https://dev.getcube.com:65532",
    "data" : [
      {
        "user_master_id" : 661,
        "provider_status" : "APPROVED",
        "bank_account_city" : "Athens",
        "provider_capture_state" : "NotApplicable",
        "last_update" : "2014-01-16T21:39:36",
        "retrieval_id" : 4,
        "created" : "2014-01-16T21:39:35",
        "provider_status_message" : "P21:NO NEG REPORTS",
        "company_id" : 18,
        "bank_account_routing_number" : "123123123",
        "ledgered" : 0,
        "provider_status_code" : "A01",
        "bank_account_last_name" : "Pants",
        "bank_account_account_number" : "1231231234",
        "bank_account_address_2" : "",
        "net_amount" : 1.01,
        "retrieval_amount" : 1.01,
        "settlement_transaction_token" : "B41BB60D-942C-46DB-99F8-D3308F3ECA3D",
        "provider" : "payments-gateway-ach",
        "location_id" : 622,
        "bank_account_state" : "TN",
        "bank_account_company_name" : "",
        "ledger_after" : "2014-01-16T21:39:35",
        "ledger_guid" : "c7282787-b533-41bd-bdf0-a2847681ccee",
        "bank_account_id" : 167,
        "bank_account_country" : "USA",
        "bank_account_address_1" : "Linkin Park",
        "bank_account_postal_code" : "37303",
        "bank_account_phone" : "1231231234",
        "provider_transaction_state" : "NotApplicable",
        "bank_account_phone_country_code" : "1",
        "bank_account_type" : "Personal Checking",
        "notes" : "",
        "bank_account_first_name" : "Nerd",
        "fee_amount" : 0
      }
    ],
    "data_md5" : "EDAA3A294B8298FC342468CD78E34A98"
  }
  eos
end

def successful_retrieval_response
  <<-eos
  {
    "custom" : null,
    "method" : "POST",
    "operation" : "POST retrieval manual",
    "id" : 0,
    "milliseconds" : "1235.30",
    "obj" : null,
    "success" : true,
    "timezone" : "",
    "endpoint" : "https://dev.getcube.com:65532",
    "data" : {
      "settlement_id" : 210,
      "provider_status_code" : "A01",
      "provider_status_message" : "P21:NO NEG REPORTS",
      "provider" : "payments-gateway-ach",
      "account_number" : "1231231234",
      "amount" : 1.01,
      "company_id" : 18,
      "provider_transaction_state" : "NotApplicable",
      "location_id" : 622,
      "settlement_transaction_token" : "B41BB60D-942C-46DB-99F8-D3308F3ECA3D",
      "routing_number" : "123123123",
      "provider_capture_state" : "NotApplicable",
      "provider_status" : "APPROVED",
      "is_approved" : true
    },
    "data_md5" : "E3C91AA3D9C1C902492C2FBDE4F3C897"
  }
  eos
end

def failed_retrieval_response
  <<-eos
  {
    "custom" : null,
    "method" : "POST",
    "operation" : "POST retrieval manual",
    "id" : 0,
    "milliseconds" : "147.47",
    "obj" : null,
    "success" : false,
    "timezone" : "",
    "endpoint" : "https://dev.getcube.com:65532",
    "data" : {
      "error_code" : "91",
      "error_text" : "Unable to process request.  Could not create retrieval record for ACH retrieval request.",
      "error_file" : "l_post_manual_retrieval.cs"
    },
    "data_md5" : "FBB8D5D13D7B2B1BCBB85E061300902B"
  }
  eos
end

def ledgered_retrieval_object
  {
    "user_master_id" => 264,
    "provider_status" => "APPROVED",
    "bank_account_city" => "San Jose",
    "provider_capture_state" => "NotApplicable",
    "last_update" => "2013-12-14T20:15:00",
    "retrieval_id" => 3,
    "created" => "2013-12-12T19:47:50",
    "provider_status_message" => "P70=>VALIDATED",
    "company_id" => 182,
    "bank_account_routing_number" => "123123123",
    "ledgered" => 1,
    "provider_status_code" => "A01",
    "bank_account_last_name" => "Booster",
    "bank_account_account_number" => "124124124",
    "bank_account_address_2" => "",
    "net_amount" => 4.75,
    "retrieval_amount" => 5,
    "settlement_transaction_token" => "C886B532-1564-498A-B5E6-CDE7D61111FB",
    "provider" => "payments-gateway-ach",
    "location_id" => 254,
    "bank_account_state" => "CA",
    "bank_account_company_name" => "",
    "ledger_after" => "2013-12-14T19:47:50",
    "ledger_guid" => "88dc0bc9-d8b1-4da3-b085-2ac1d609cdc5",
    "bank_account_id" => 0,
    "bank_account_country" => "USA",
    "bank_account_address_1" => "123 dummy st",
    "bank_account_postal_code" => "12345",
    "bank_account_phone" => "1231231234",
    "provider_transaction_state" => "NotApplicable",
    "bank_account_phone_country_code" => "1",
    "bank_account_type" => "Personal Checking",
    "notes" => "Test!",
    "bank_account_first_name" => "Bobby",
    "fee_amount" => 0.25
  }
end

def unledgered_retrieval_object
  {
    "user_master_id" => 264,
    "provider_status" => "APPROVED",
    "bank_account_city" => "San Jose",
    "provider_capture_state" => "NotApplicable",
    "last_update" => "2013-12-14T20:15:00",
    "retrieval_id" => 3,
    "created" => "2013-12-12T19:47:50",
    "provider_status_message" => "P70=>VALIDATED",
    "company_id" => 182,
    "bank_account_routing_number" => "123123123",
    "ledgered" => 0,
    "provider_status_code" => "A01",
    "bank_account_last_name" => "Booster",
    "bank_account_account_number" => "124124124",
    "bank_account_address_2" => "",
    "net_amount" => 4.75,
    "retrieval_amount" => 5,
    "settlement_transaction_token" => "C886B532-1564-498A-B5E6-CDE7D61111FB",
    "provider" => "payments-gateway-ach",
    "location_id" => 254,
    "bank_account_state" => "CA",
    "bank_account_company_name" => "",
    "ledger_after" => "2013-12-14T19:47:50",
    "ledger_guid" => "88dc0bc9-d8b1-4da3-b085-2ac1d609cdc5",
    "bank_account_id" => 0,
    "bank_account_country" => "USA",
    "bank_account_address_1" => "123 dummy st",
    "bank_account_postal_code" => "12345",
    "bank_account_phone" => "1231231234",
    "provider_transaction_state" => "NotApplicable",
    "bank_account_phone_country_code" => "1",
    "bank_account_type" => "Personal Checking",
    "notes" => "Test!",
    "bank_account_first_name" => "Bobby",
    "fee_amount" => 0.25
  }
end

def failed_balance_response
  <<-eos
  {
    "custom" : null,
    "method" : "POST",
    "operation" : "POST settlement balance",
    "id" : 0,
    "milliseconds" : "13.67",
    "obj" : null,
    "success" : false,
    "timezone" : "",
    "endpoint" : "https://dev.getcube.com:65532",
    "data" : {
      "error_code" : "1",
      "error_text" : "The requested object was not found.",
      "error_file" : "l_post_settlement_balance.cs"
    },
    "data_md5" : "05DAC0B9E77750348A4A529E7615C054"
  }
  eos
end

def successful_balance_response
  <<-eos
  {
    "custom" : null,
    "method" : "POST",
    "operation" : "POST settlement balance",
    "id" : 622,
    "milliseconds" : "173.83",
    "obj" : null,
    "success" : true,
    "timezone" : "",
    "endpoint" : "https://dev.getcube.com:65532",
    "data" : 15.00,
    "data_md5" : "F7DDD489AB0A82567B241B05971CBDB3"
  }
  eos
end